@@ -8,6 +8,7 @@ from .legend import _tpl_legend
 from .strutils import _savetext, _compactify
 from .logmodes import _tpl_logmodes
 from .ticklabel import _tpl_ticklabel
+from .cycle_list import _tpl_cycle_list
 
 
 class figure:
@@ -26,6 +27,7 @@ class figure:
     self.__type: str = "xy"
     self.__logmodes: _tpl_logmodes = _tpl_logmodes()
     self.__additional_axis_cmds: list[str] = []
+    self.__cycle_list: _tpl_cycle_list = _tpl_cycle_list("multi")
 
   def plot(self, x: Iterable, y: Iterable, xerror: Iterable = None, yerror: Iterable = None,
            *args, **kwargs):
@@ -143,6 +145,9 @@ class figure:
   def add_axis_command(self, cmd: str):
     self.__additional_axis_cmds.append(cmd)
 
+  def repeat_style(self, ntimes: int = None):
+    self.__cycle_list.repeat_style(ntimes)
+
   def __create_tex(self):
     preable_cmd = """\\documentclass[tikz]{standalone}\n
 \\usepackage{pgfplots}
@@ -175,7 +180,8 @@ class figure:
   grid style=dotted,
   scale only axis,
   {self.__logmodes.x}
-  {self.__logmodes.y}"""
+  {self.__logmodes.y}
+  {self.__cycle_list}"""
     body_cmd += ''.join(["\n  " + x + "," for x in self.__additional_axis_cmds])
     body_cmd += "\n]\n\n"
 
